You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@skywalking.apache.org by li...@apache.org on 2021/11/30 04:53:02 UTC

[skywalking-goapi] branch main updated: Add data for batch meter protocol (#20)

This is an automated email from the ASF dual-hosted git repository.

liuhan pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/skywalking-goapi.git


The following commit(s) were added to refs/heads/main by this push:
     new aee6db9  Add data for batch meter protocol (#20)
aee6db9 is described below

commit aee6db90e633eaf70e2ae435873a38aebea65e7f
Author: mrproliu <74...@qq.com>
AuthorDate: Tue Nov 30 12:52:56 2021 +0800

    Add data for batch meter protocol (#20)
---
 satellite/data/v1/SniffData.pb.go | 44 +++++++++++++++++++++++++++++----------
 satellite/data/v1/SniffData.proto |  1 +
 2 files changed, 34 insertions(+), 11 deletions(-)

diff --git a/satellite/data/v1/SniffData.proto b/satellite/data/v1/SniffData.proto
index 19e40bd..26d4a03 100644
--- a/satellite/data/v1/SniffData.proto
+++ b/satellite/data/v1/SniffData.proto
@@ -87,6 +87,7 @@ message SniffData {
     EnvoyALSV3List envoyALSV3List = 21;
     EnvoyMetricsV2List envoyMetricsV2List = 22;
     EnvoyMetricsV3List envoyMetricsV3List = 23;
+    MeterDataCollection meterCollection = 24;
   }
 }
diff --git a/satellite/data/v1/SniffData.pb.go b/satellite/data/v1/SniffData.pb.go
index ec7cc86..e8ce6fd 100644
--- a/satellite/data/v1/SniffData.pb.go
+++ b/satellite/data/v1/SniffData.pb.go
@@ -166,6 +166,7 @@ type SniffData struct {
 	//	*SniffData_EnvoyALSV3List
 	//	*SniffData_EnvoyMetricsV2List
 	//	*SniffData_EnvoyMetricsV3List
+	//	*SniffData_MeterCollection
 	Data isSniffData_Data `protobuf_oneof:"data"`
 }
 
@@ -369,6 +370,13 @@ func (x *SniffData) GetEnvoyMetricsV3List() *EnvoyMetricsV3List {
 	return nil
 }
 
+func (x *SniffData) GetMeterCollection() *v3.MeterDataCollection {
+	if x, ok := x.GetData().(*SniffData_MeterCollection); ok {
+		return x.MeterCollection
+	}
+	return nil
+}
+
 type isSniffData_Data interface {
 	isSniffData_Data()
 }
@@ -445,6 +453,10 @@ type SniffData_EnvoyMetricsV3List struct {
 	EnvoyMetricsV3List *EnvoyMetricsV3List `protobuf:"bytes,23,opt,name=envoyMetricsV3List,proto3,oneof"`
 }
 
+type SniffData_MeterCollection struct {
+	MeterCollection *v3.MeterDataCollection `protobuf:"bytes,24,opt,name=meterCollection,proto3,oneof"`
+}
+
 func (*SniffData_Clr) isSniffData_Data() {}
 
 func (*SniffData_Jvm) isSniffData_Data() {}
@@ -481,6 +493,8 @@ func (*SniffData_EnvoyMetricsV2List) isSniffData_Data() {}
 
 func (*SniffData_EnvoyMetricsV3List) isSniffData_Data() {}
 
+func (*SniffData_MeterCollection) isSniffData_Data() {}
+
 type EnvoyALSV2List struct {
 	state         protoimpl.MessageState
 	sizeCache     protoimpl.SizeCache
@@ -697,7 +711,7 @@ var file_satellite_SniffData_proto_rawDesc = []byte{
 	0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x2e, 0x65,
 	0x6e, 0x76, 0x6f, 0x79, 0x2f, 0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x2f, 0x6d, 0x65, 0x74,
 	0x72, 0x69, 0x63, 0x73, 0x2f, 0x76, 0x33, 0x2f, 0x6d, 0x65, 0x74, 0x72, 0x69, 0x63, 0x73, 0x5f,
-	0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x8c, 0x0b,
+	0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xdc, 0x0b,
 	0x0a, 0x09, 0x53, 0x6e, 0x69, 0x66, 0x66, 0x44, 0x61, 0x74, 0x61, 0x12, 0x1c, 0x0a, 0x09, 0x74,
 	0x69, 0x6d, 0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x18, 0x01, 0x20, 0x01, 0x28, 0x03, 0x52, 0x09,
 	0x74, 0x69, 0x6d, 0x65, 0x73, 0x74, 0x61, 0x6d, 0x70, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d,
@@ -782,7 +796,12 @@ var file_satellite_SniffData_proto_rawDesc = []byte{
 	0x28, 0x0b, 0x32, 0x21, 0x2e, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69, 0x6e, 0x67, 0x2e,
 	0x76, 0x33, 0x2e, 0x45, 0x6e, 0x76, 0x6f, 0x79, 0x4d, 0x65, 0x74, 0x72, 0x69, 0x63, 0x73, 0x56,
 	0x33, 0x4c, 0x69, 0x73, 0x74, 0x48, 0x00, 0x52, 0x12, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x4d, 0x65,
-	0x74, 0x72, 0x69, 0x63, 0x73, 0x56, 0x33, 0x4c, 0x69, 0x73, 0x74, 0x1a, 0x37, 0x0a, 0x09, 0x4d,
+	0x74, 0x72, 0x69, 0x63, 0x73, 0x56, 0x33, 0x4c, 0x69, 0x73, 0x74, 0x12, 0x4e, 0x0a, 0x0f, 0x6d,
+	0x65, 0x74, 0x65, 0x72, 0x43, 0x6f, 0x6c, 0x6c, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x18, 0x18,
+	0x20, 0x01, 0x28, 0x0b, 0x32, 0x22, 0x2e, 0x73, 0x6b, 0x79, 0x77, 0x61, 0x6c, 0x6b, 0x69, 0x6e,
+	0x67, 0x2e, 0x76, 0x33, 0x2e, 0x4d, 0x65, 0x74, 0x65, 0x72, 0x44, 0x61, 0x74, 0x61, 0x43, 0x6f,
+	0x6c, 0x6c, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x48, 0x00, 0x52, 0x0f, 0x6d, 0x65, 0x74, 0x65,
+	0x72, 0x43, 0x6f, 0x6c, 0x6c, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x1a, 0x37, 0x0a, 0x09, 0x4d,
 	0x65, 0x74, 0x61, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18,
 	0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61,
 	0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65,
@@ -864,8 +883,9 @@ var file_satellite_SniffData_proto_goTypes = []interface{}{
 	(*v32.ProfileTaskFinishReport)(nil),  // 16: skywalking.v3.ProfileTaskFinishReport
 	(*v35.Commands)(nil),                 // 17: skywalking.v3.Commands
 	(*v36.ConfigurationSyncRequest)(nil), // 18: skywalking.v3.ConfigurationSyncRequest
-	(*v2.StreamMetricsMessage)(nil),      // 19: envoy.service.metrics.v2.StreamMetricsMessage
-	(*v37.StreamMetricsMessage)(nil),     // 20: envoy.service.metrics.v3.StreamMetricsMessage
+	(*v3.MeterDataCollection)(nil),       // 19: skywalking.v3.MeterDataCollection
+	(*v2.StreamMetricsMessage)(nil),      // 20: envoy.service.metrics.v2.StreamMetricsMessage
+	(*v37.StreamMetricsMessage)(nil),     // 21: envoy.service.metrics.v3.StreamMetricsMessage
 }
 var file_satellite_SniffData_proto_depIdxs = []int32{
 	0,  // 0: skywalking.v3.SniffData.type:type_name -> skywalking.v3.SniffType
@@ -886,13 +906,14 @@ var file_satellite_SniffData_proto_depIdxs = []int32{
 	3,  // 15: skywalking.v3.SniffData.envoyALSV3List:type_name -> skywalking.v3.EnvoyALSV3List
 	4,  // 16: skywalking.v3.SniffData.envoyMetricsV2List:type_name -> skywalking.v3.EnvoyMetricsV2List
 	5,  // 17: skywalking.v3.SniffData.envoyMetricsV3List:type_name -> skywalking.v3.EnvoyMetricsV3List
-	19, // 18: skywalking.v3.EnvoyMetricsV2List.messages:type_name -> envoy.service.metrics.v2.StreamMetricsMessage
-	20, // 19: skywalking.v3.EnvoyMetricsV3List.messages:type_name -> envoy.service.metrics.v3.StreamMetricsMessage
-	20, // [20:20] is the sub-list for method output_type
-	20, // [20:20] is the sub-list for method input_type
-	20, // [20:20] is the sub-list for extension type_name
-	20, // [20:20] is the sub-list for extension extendee
-	0,  // [0:20] is the sub-list for field type_name
+	19, // 18: skywalking.v3.SniffData.meterCollection:type_name -> skywalking.v3.MeterDataCollection
+	20, // 19: skywalking.v3.EnvoyMetricsV2List.messages:type_name -> envoy.service.metrics.v2.StreamMetricsMessage
+	21, // 20: skywalking.v3.EnvoyMetricsV3List.messages:type_name -> envoy.service.metrics.v3.StreamMetricsMessage
+	21, // [21:21] is the sub-list for method output_type
+	21, // [21:21] is the sub-list for method input_type
+	21, // [21:21] is the sub-list for extension type_name
+	21, // [21:21] is the sub-list for extension extendee
+	0,  // [0:21] is the sub-list for field type_name
 }
 
 func init() { file_satellite_SniffData_proto_init() }
@@ -981,6 +1002,7 @@ func file_satellite_SniffData_proto_init() {
 		(*SniffData_EnvoyALSV3List)(nil),
 		(*SniffData_EnvoyMetricsV2List)(nil),
 		(*SniffData_EnvoyMetricsV3List)(nil),
+		(*SniffData_MeterCollection)(nil),
 	}
 	type x struct{}
 	out := protoimpl.TypeBuilder{